@@ -44,7 +44,10 @@ class GoogleAPIResource(Resource):
     readiness_value = None
     readiness_terminal_values = []
 
-    def __init__(self, client_kwargs={}, **resource_data):
+    def __init__(self, client_kwargs=None, **resource_data):
+
+        if client_kwargs is None:
+            client_kwargs = {}
 
         # Set some defaults
         self._service = None
@@ -114,14 +117,19 @@ class GoogleAPIResource(Resource):
             raise ResourceException('Unrecognized resource type: {}'.format(resource_type))
 
     @classmethod
-    def from_resource_data(cls, *, resource_type, client_kwargs={}, **resource_data):
+    def from_resource_data(cls, *, resource_type, client_kwargs=None, **resource_data):
+        if client_kwargs is None:
+            client_kwargs = {}
         res_cls = cls.subclass_by_type(resource_type)
         return res_cls(client_kwargs=client_kwargs, **resource_data)
 
     @staticmethod
-    def from_cai_data(resource_name, resource_type, project_id=None, client_kwargs={}):
+    def from_cai_data(resource_name, resource_type, project_id=None, client_kwargs=None):
         ''' Attempt to return the appropriate resource using Cloud Asset Inventory-formatted resource info '''
 
+        if client_kwargs is None:
+            client_kwargs = {}
+
         res_cls = GoogleAPIResource.subclass_by_type(resource_type)
 
         resource_data = GoogleAPIResource._extract_cai_name_data(resource_name)
@@ -555,6 +563,37 @@ class GcpDataprocCluster(GoogleAPIResource):
         }
 
 
+class GcpDatafusionInstance(GoogleAPIResource):
+    service_name = "datafusion"
+    resource_path = "projects.locations.instances"
+    version = "v1beta1"
+
+    required_resource_data = ['name', 'location', 'project_id']
+
+    resource_components = {
+        'iam': 'getIamPolicy',
+    }
+
+    resource_type = "datafusion.googleapis.com/Instance"
+
+    def _get_request_args(self):
+        return {
+            'name': 'projects/{}/locations/{}/instances/{}'.format(
+                self.project_id,
+                self._resource_data['location'],
+                self._resource_data['name'],
+            )
+        }
+
+    def _get_iam_request_args(self):
+        return {
+            'resource': 'projects/{}/locations/{}/instances/{}'.format(
+                self.project_id,
+                self._resource_data['location'],
+                self._resource_data['name'],
+            )
+        }
+
 
 class GcpGkeCluster(GoogleAPIResource):
 
@@ -705,6 +744,28 @@ class GcpSqlInstance(GoogleAPIResource):
             'project': self._resource_data['project_id']
         }
 
+class GcpOrganization(GoogleAPIResource):
+
+    service_name = "cloudresourcemanager"
+    resource_path = "organizations"
+    version = "v1"
+
+    resource_components = {
+        'iam': 'getIamPolicy',
+    }
+
+    resource_type = "cloudresourcemanager.googleapis.com/Organization"
+
+    def _get_request_args(self):
+        return {
+            'name': 'organizations/' + self._resource_data['name']
+        }
+
+    def _get_iam_request_args(self):
+        return {
+            'resource': 'organizations/' + self._resource_data['name']
+        }
+
 
 class GcpProject(GoogleAPIResource):
 
